# -*- coding: UTF-8 -*-
# Copyright 2017-2023 Rumma & Ko Ltd
# License: GNU Affero General Public License v3 (see file COPYING for details)
"""Some demo data.

"""

from lino.api import dd, rt, _
from lino.utils.mldbc import babel_named as named


def objects():
    Topic = rt.models.topics.Topic
    EventType = rt.models.cal.EventType
    Room = rt.models.cal.Room

    school = named(Room, _("School"))
    yield school
    center = named(Room, _("Youth center"))
    yield center
    library = named(Room, _("Library"))
    yield library

    training = named(EventType, _("Training"))
    yield training
    workshop = named(EventType, _("Travel"))
    yield workshop
    camp = named(EventType, _("Camp"))
    yield camp

    nature = named(Topic, _("Nature"))
    yield nature
    folk = named(Topic, _("Folk"))
    yield folk
    health = named(Topic, _("Health"))
    yield health
    comp = named(Topic, _("Computer"))
    yield comp



# -*- coding: UTF-8 -*-
# Copyright 2023 Rumma & Ko
# License: GNU Affero General Public License v3 (see file COPYING for details)
"""Database models for :mod:`lino_amici.lib.cal`.

"""

from lino_xl.lib.cal.models import *


@classmethod
def get_simple_parameters(cls):
    for p in super(Events, cls).get_simple_parameters():
        yield p
    yield 'room__calendar'


Events.get_simple_parameters = get_simple_parameters

Events.params_layout = "start_date end_date user event_type room room__calendar project presence_guest"
AllEntries.params_layout = """
    start_date end_date observed_event state
    user assigned_to project event_type room room__calendar show_appointments
    """



# Copyright 2016-2018 Rumma & Ko Ltd
# License: GNU Affero General Public License v3 (see file COPYING for details)

from lino.modlib.users.ui import *
from lino.modlib.office.roles import OfficeUser
from lino.api import dd, _


class UserDetail(UserDetail):

    main = "general calendar dashboard.WidgetsByUser comments.CommentsByRFC"

    general = dd.Panel("""
    box1
    remarks:40 AuthoritiesGiven:20
    groups.MembershipsByUser
    """,
                       label=_("General"))

    calendar = dd.Panel("""
    event_type
    cal.SubscriptionsByUser
    # cal.MembershipsByUser
    """,
                        label=dd.plugins.cal.verbose_name,
                        required_roles=dd.login_required(OfficeUser))

    box1 = """
    username user_type:20 partner
    first_name last_name initials
    email language
    id created modified
    """


# Users.detail_layout = UserDetail()



# -*- coding: UTF-8 -*-
# Copyright 2017 Rumma & Ko Ltd
# License: GNU Affero General Public License v3 (see file COPYING for details)
"""Extended and specific plugins for Lino Noi.

.. autosummary::
   :toctree:

    contacts
    amici

"""



# import os ; print "20161219 %s (pid:%s)" % (__name__, os.getpid())

import datetime
from lino.core.auth.utils import activate_social_auth_testing
from ..settings import *


class Site(Site):
    is_demo_site = True
    the_demo_date = datetime.date(2019, 12, 16)
    languages = "en de fr"

    # is_demo_site = False

    # default_ui = 'lino.modlib.extjs'
    # default_ui = 'lino.modlib.bootstrap3'
    # default_user = 'anonymous'

    def get_plugin_configs(self):
        for i in super().get_plugin_configs():
            yield i
        # yield 'addresses', 'partner_model', 'contacts.Person'
        yield 'users', 'third_party_authentication', True


activate_social_auth_testing(globals(),
                             google=False,
                             github=False,
                             wikimedia=False)

SITE = Site(globals())
# print "20161219 b"
DEBUG = True

# the following line should not be active in a checked-in version
# DATABASES['default']['NAME'] = ':memory:'



# -*- coding: UTF-8 -*-
# Copyright 2016-2019 Rumma & Ko Ltd
# License: GNU Affero General Public License v3 (see file COPYING for details)
"""The default :attr:`workflows_module
<lino.core.site.Site.workflows_module>` for :ref:`amici` applications.

"""

# from lino_noi.lib.tickets.workflows import *
from lino_xl.lib.cal.workflows.voga import *
from lino_xl.lib.courses.workflows.std import *

# from lino_xl.lib.courses.workflows import *
# from lino_xl.lib.contacts.roles import ContactsStaff

# from lino.api import dd, rt
# lib = rt.models
# for m in (lib.contacts.Person, lib.contacts.Company, lib.countries.Place):
#     #~ print repr(m)
#     m.define_action(merge_row=dd.MergeAction(
#         m, required_roles=set([ContactsStaff])))

EntryStates.took_place.guest_state = GuestStates.present
EntryStates.cancelled.guest_state = GuestStates.excused
# EntryStates.missed.guest_state = GuestStates.missing
